package net.sf.statscm;

/*
 * Copyright 2006 Doug Culnane
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import net.sf.statcvs.output.ConfigurationException;

import org.apache.maven.model.Model;
import org.apache.maven.model.Scm;
import org.apache.maven.model.IssueManagement;
import org.apache.maven.project.MavenProject;

import junit.framework.TestCase;

/**
 * Tests StatXXX Configuration form Maven Project.
 * 
 * @author DoCulnan
 * 
 */
public class StatConfTest extends TestCase
{

    /**
     * Test Extract Connection Type.
     * 
     */
    public void testExtractConnectionType()
    {
        assertEquals( StatConf.CONNECTION_TYPE_CVS, StatConf.extractConnectionType( "scm:cvs:..." ) );
        assertEquals(
                      StatConf.CONNECTION_TYPE_CVS,
                      StatConf.extractConnectionType( "scm:cvs:pserver:anonymous@statcvs.cvs.sourceforge.net:/cvsroot/statcvs/statcvs" ) );

        assertEquals( StatConf.CONNECTION_TYPE_SVN,
                      StatConf.extractConnectionType( "svn:https://svn.sourceforge.net/svnroot/stat-scm/trunk" ) );
    }

    /**
     * Test to make sure that null pointers are handled, and errors are throwen corectly.
     * 
     */
    public void testConfugureFromPOM()
    {

        MavenProject project = new MavenProject( new Model() );
        try
        {
            StatConf.configure( project );
            fail( "The above should throw an error." );
        }
        catch ( ConfigurationException e )
        {
            assertEquals( e.getMessage(), StatScmMojo.getResourceBundle().getString( "error.config.no_scm_in_pom" ) );
        }
        Scm scm = new Scm();
        project.setScm( scm );
        try
        {
            StatConf.configure( project );
            fail( "This should throw an error." );
        }
        catch ( ConfigurationException e )
        {
            assertEquals( e.getMessage(),
                          StatScmMojo.getResourceBundle().getString( "error.config.no_scm_connection_url_in_pom" ) );
        }
        scm.setConnection( "" );
        try
        {
            StatConf.configure( project );
            fail( "This should throw an error." );
        }
        catch ( ConfigurationException e )
        {
            assertEquals( e.getMessage(),
                          StatScmMojo.getResourceBundle().getString( "error.config.no_scm_connection_url_in_pom" ) );
        }
        scm.setConnection( "" );
        try
        {
            StatConf.configure( project );
            fail( "This should throw an error." );
        }
        catch ( ConfigurationException e )
        {
            assertEquals( e.getMessage(),
                          StatScmMojo.getResourceBundle().getString( "error.config.no_scm_connection_url_in_pom" ) );
        }
        scm.setDeveloperConnection( "svn:https://svn.sourceforge.net/svnroot/stat-scm/trunk" );
        try
        {
            StatConf.configure( project );
            assertEquals( StatConf.CONNECTION_TYPE_SVN, StatConf.getConnectionType() );
        }
        catch ( ConfigurationException e )
        {
            fail( "This should not throw an error." );
        }
    }

    /**
     * 
     * @throws ConfigurationException
     */
    public void testScmTypeRecognition() throws ConfigurationException
    {
        MavenProject project = new MavenProject( new Model() );
        Scm scm = new Scm();
        project.setScm( scm );

        scm.setConnection( "scm:cvs:pserver:anonymous@statcvs.cvs.sourceforge.net:/cvsroot/statcvs/statcvs" );
        StatConf.configure( project );
        assertTrue( StatConf.isStatCVS() );
        assertFalse( StatConf.isStatSVN() );
        assertEquals( "cvs", StatConf.getConnectionType() );

        scm.setConnection( "svn:https://svn.sourceforge.net/svnroot/stat-scm/trunk" );
        StatConf.configure( project );
        assertFalse( StatConf.isStatCVS() );
        assertTrue( StatConf.isStatSVN() );

        assertEquals( "svn", StatConf.getConnectionType() );
    }

    /**
     * Test that the Buzilla integration is configured.
     * 
     * @throws ConfigurationException
     */
    public void testSetBugZilla() throws ConfigurationException
    {
        
        String url = "http://sourceforge.net/tracker/?group_id=182522";
        
        MavenProject project = new MavenProject( new Model() );
        Scm scm = new Scm();
        project.setScm( scm );
        scm.setConnection("scm:svn:http....");
        IssueManagement im = new IssueManagement();
        im.setSystem( "none" );
        im.setUrl( url );
        project.setIssueManagement( im );
        StatConf.configure( project );
        // assertEqulas( "", StatConf.getBugzillaUrl() );
        im.setSystem( "bugzilla" );
        StatConf.configure( project );
        // assertEqulas( url, StatConf.getBugzillaUrl() );
    }
 
    /**
     * 
     * @throws ConfigurationException
     */
    public void testConfugureViewVC() throws ConfigurationException
    {

        MavenProject project = new MavenProject( new Model() );
        Scm scm = new Scm();
        project.setScm( scm );
        scm.setConnection( "scm:svn:https://svn.sourceforge.net/svnroot/stat-scm/trunk" );
        scm.setUrl( "http://stat-scm.svn.sourceforge.net/viewvc/stat-scm/trunk/" );
        StatConf.configure( project );
        assertEquals( "net.sf.statcvs.output.ViewVcIntegration", StatConf.getWebRepository().getClass().getName() );
    }
}
